@@ -2,10 +2,16 @@ use crate::TailwindSizing;
 
 use super::*;
 
-pub use self::{select::TailwindSelect, torch::TailwindTorch};
+pub use self::{
+    cursor::TailwindCursor, pointer::TailwindPointerEvents, resize::TailwindResize, select::TailwindSelect,
+    torch::TailwindTorch,
+};
 
+mod cursor;
 mod display;
 mod parser;
+mod pointer;
+mod resize;
 mod select;
 mod torch;
 
@@ -19,22 +25,10 @@ pub enum TailwindAppearance {
     None,
 }
 
-#[doc=include_str!("grid-row.md")]
-#[derive(Debug, Copy, Clone)]
-pub enum TailwindCursor {}
-
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindCaretColor {}
 
-#[doc=include_str!("grid-row.md")]
-#[derive(Debug, Copy, Clone)]
-pub enum TailwindPointerEvents {}
-
-#[doc=include_str!("grid-row.md")]
-#[derive(Debug, Copy, Clone)]
-pub enum TailwindResize {}
-
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
 pub struct TailwindScrollSize {
