@@ -10,6 +10,7 @@ pub struct TailwindVisibility {
 enum Visibility {
     Visible,
     Invisible,
+    Global(CssBehavior),
 }
 
 impl Display for TailwindVisibility {
@@ -17,6 +18,7 @@ impl Display for TailwindVisibility {
         match self.kind {
             Visibility::Visible => write!(f, "visible"),
             Visibility::Invisible => write!(f, "invisible"),
+            Visibility::Global(g) => write!(f, "visible-{}", g),
         }
     }
 }
@@ -24,11 +26,12 @@ impl Display for TailwindVisibility {
 impl TailwindInstance for TailwindVisibility {
     fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
         let visibility = match self.kind {
-            Visibility::Visible => "visible",
-            Visibility::Invisible => "hidden",
+            Visibility::Visible => "visible".to_string(),
+            Visibility::Invisible => "hidden".to_string(),
+            Visibility::Global(g) => g.to_string(),
         };
         css_attributes! {
-         "visibility" =>    visibility
+            "visibility" => visibility
         }
     }
 }
