@@ -10,7 +10,7 @@ impl TailwindInstruction {
         let instance = match element.as_slice() {
             // Layout System
             ["aspect", rest @ ..] => TailwindAspect::parse(rest, arbitrary)?.boxed(),
-            ["container"] => TailwindContainer {}.boxed(),
+            ["container"] => TailwindContainer::default().boxed(),
             ["columns", rest @ ..] => TailwindColumns::parse(rest, arbitrary)?.boxed(),
             ["break", rest @ ..] => Self::break_adaptor(rest, arbitrary)?,
             ["box", rest @ ..] => Self::box_adaptor(rest, arbitrary)?,
@@ -47,11 +47,11 @@ impl TailwindInstruction {
             // https://tailwindcss.com/docs/position#header
             [s @ ("static" | "fixed" | "absolute" | "relative" | "sticky")] => TailwindPosition::from(*s).boxed(),
             // https://tailwindcss.com/docs/top-right-bottom-left
-            ["inset", _rest @ ..] => todo!(),
-            ["top", _rest @ ..] => todo!(),
-            ["right", _rest @ ..] => todo!(),
-            ["buttom", _rest @ ..] => todo!(),
-            ["left", _rest @ ..] => todo!(),
+            ["inset", rest @ ..] => TailwindInset::parse(rest, arbitrary, neg)?.boxed(),
+            ["top", rest @ ..] => TailwindTop::parse(rest, arbitrary, neg)?.boxed(),
+            ["right", rest @ ..] => TailwindRight::parse(rest, arbitrary, neg)?.boxed(),
+            ["bottom", rest @ ..] => TailwindBottom::parse(rest, arbitrary, neg)?.boxed(),
+            ["left", rest @ ..] => TailwindLeft::parse(rest, arbitrary, neg)?.boxed(),
             // https://tailwindcss.com/docs/visibility
             ["visible"] => TailwindVisibility::Visible.boxed(),
             ["invisible"] => TailwindVisibility::Invisible.boxed(),
@@ -63,14 +63,12 @@ impl TailwindInstruction {
             ["grow", rest @ ..] => TailWindGrow::parse(rest, arbitrary)?.boxed(),
             ["shrink", rest @ ..] => TailWindShrink::parse(rest, arbitrary)?.boxed(),
             ["order", rest @ ..] => TailWindOrder::parse(rest, arbitrary, self.negative)?.boxed(),
-            ["grid", rest @ ..] => Self::grid_adaptor(rest, arbitrary)?,
+            ["grid", rest @ ..] => TailwindGrid::parse(rest, arbitrary)?,
             // https://tailwindcss.com/docs/grid-column
             ["col", rest @ ..] => TailwindColumn::parse(rest, arbitrary)?.boxed(),
             ["row", rest @ ..] => TailwindRow::parse(rest, arbitrary)?.boxed(),
             ["auto", rest @ ..] => TailwindGridAuto::parse(rest, arbitrary)?.boxed(),
-            ["gap", "x", rest @ ..] => TailwindGap::parse_x(rest, arbitrary)?.boxed(),
-            ["gap", "y", rest @ ..] => TailwindGap::parse_y(rest, arbitrary)?.boxed(),
-            ["gap", rest @ ..] => TailwindGap::parse_xy(rest, arbitrary)?.boxed(),
+            ["gap", rest @ ..] => TailwindGap::parse(rest, arbitrary)?.boxed(),
             ["justify", rest @ ..] => Self::justify_adaptor(rest, arbitrary)?,
             ["content", rest @ ..] => Self::content_adaptor(rest, arbitrary)?,
             ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
@@ -112,12 +110,12 @@ impl TailwindInstruction {
             // https://tailwindcss.com/docs/letter-spacing
             ["tracking", rest @ ..] => TailwindTracking::parse(rest, arbitrary)?.boxed(),
             ["leading", rest @ ..] => TailwindLeading::parse(rest, arbitrary)?.boxed(),
-            ["list", rest @ ..] => Self::list_adaptor(rest, arbitrary)?,
+            ["list", rest @ ..] => TailwindList::parse(rest, arbitrary)?,
             // https://tailwindcss.com/docs/text-decoration
-            ["underline"] => TailwindDecorationLine::Underline.boxed(),
-            ["overline"] => TailwindDecorationLine::Overline.boxed(),
-            ["line", "through"] => TailwindDecorationLine::ThroughLine.boxed(),
-            ["no", "underline"] => TailwindDecorationLine::None.boxed(),
+            ["underline"] => TailwindDecorationLine::from("underline").boxed(),
+            ["overline"] => TailwindDecorationLine::from("overline").boxed(),
+            ["line", "through"] => TailwindDecorationLine::from("line-through").boxed(),
+            ["no", "underline"] => TailwindDecorationLine::from("none").boxed(),
             // https://tailwindcss.com/docs/text-decoration-color
             ["decoration", rest @ ..] => TailwindDecoration::parse(rest, arbitrary)?,
             ["underline", "offset", rest @ ..] => TailwindUnderlineOffset::parse(rest, arbitrary)?.boxed(),
@@ -136,11 +134,10 @@ impl TailwindInstruction {
             // Typography System Extension
             ["prose"] => todo!(),
             // Backgrounds System
-            // FIXME: https://tailwindcss.com/docs/background-blend-mode
             ["bg", rest @ ..] => Self::bg_adaptor(rest, arbitrary)?,
-            ["from", _rest @ ..] => todo!(),
-            ["via", _rest @ ..] => todo!(),
-            ["to", _rest @ ..] => todo!(),
+            ["from", rest @ ..] => TailwindFrom::parse(rest, arbitrary)?.boxed(),
+            ["via", rest @ ..] => TailwindVia::parse(rest, arbitrary)?.boxed(),
+            ["to", rest @ ..] => TailwindTo::parse(rest, arbitrary)?.boxed(),
             // Borders System
             ["rounded", rest @ ..] => TailwindRounded::parse(rest, arbitrary)?.boxed(),
             ["border", rest @ ..] => TailwindBorder::parse(rest, arbitrary)?,
@@ -149,7 +146,7 @@ impl TailwindInstruction {
             ["ring", rest @ ..] => Self::ring_adaptor(rest, arbitrary)?,
             // Effects System
             ["shadow", rest @ ..] => Self::shadow_adaptor(rest, arbitrary)?,
-            ["opacity", rest @ ..] => TailwindOpacity::parse(rest, arbitrary)?.boxed(),
+            ["opacity", rest @ ..] => TailwindOpacity::parse(rest, arbitrary, false)?.boxed(),
             ["mix", "blend", rest @ ..] => TailwindBlend::parse(rest, arbitrary)?.boxed(),
             // Filters System
             ["blur", rest @ ..] => TailwindBlur::parse(rest, arbitrary, false)?.boxed(),
@@ -165,20 +162,16 @@ impl TailwindInstruction {
             // Tables System
             ["table", rest @ ..] => Self::table_adaptor(rest, arbitrary)?,
             // Transitions System
-            ["transition", _rest @ ..] => todo!(),
+            ["transition", rest @ ..] => TailwindTransition::parse(rest, arbitrary)?.boxed(),
             ["duration", rest @ ..] => TailwindDuration::parse(rest, arbitrary)?.boxed(),
-            ["ease", _rest @ ..] => todo!(),
+            ["ease", rest @ ..] => TailwindEase::parse(rest, arbitrary)?.boxed(),
             ["delay", rest @ ..] => TailwindDelay::parse(rest, arbitrary)?.boxed(),
-            ["animate", _rest @ ..] => todo!(),
+            ["animate", rest @ ..] => todo!(),
             // Transforms System
-            ["scale", "x", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(true), neg)?.boxed(),
-            ["scale", "y", rest @ ..] => TailwindScale::parse(rest, arbitrary, Some(false), neg)?.boxed(),
-            ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, None, neg)?.boxed(),
+            ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, neg)?.boxed(),
             ["rotate", rest @ ..] => TailwindRotate::parse(rest, arbitrary, neg)?.boxed(),
-            ["translate", "x", _rest @ ..] => todo!(),
-            ["translate", "y", _rest @ ..] => todo!(),
-            ["skew", "x", rest @ ..] => TailwindSkew::parse(rest, arbitrary, true, neg)?.boxed(),
-            ["skew", "y", rest @ ..] => TailwindSkew::parse(rest, arbitrary, false, neg)?.boxed(),
+            ["translate", rest @ ..] => TailwindTranslate::parse(rest, arbitrary, neg)?.boxed(),
+            ["skew", rest @ ..] => TailwindSkew::parse(rest, arbitrary, neg)?.boxed(),
             ["origin", rest @ ..] => TailwindOrigin::parse(rest, arbitrary)?.boxed(),
             // Interactivity System
             ["accent", rest @ ..] => TailwindAccentColor::parse(rest, arbitrary)?.boxed(),
@@ -194,8 +187,8 @@ impl TailwindInstruction {
             ["select", rest @ ..] => TailwindSelect::parse(rest, arbitrary)?.boxed(),
             ["will", "change", rest @ ..] => TailwindWillChange::parse(rest, arbitrary)?.boxed(),
             // SVG System
-            ["fill", _rest @ ..] => todo!(),
-            ["stroke", _rest @ ..] => todo!(),
+            ["fill", rest @ ..] => todo!(),
+            ["stroke", rest @ ..] => todo!(),
             // Accessibility System
             ["sr", "only"] => TailwindScreenReader::new(true).boxed(),
             ["not", "sr", "only"] => TailwindScreenReader::new(false).boxed(),
@@ -325,20 +318,7 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-    #[inline]
-    fn grid_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after place");
-        let out = match str {
-            // https://tailwindcss.com/docs/grid-template-rows
-            ["rows", _rest @ ..] => TailwindListStyle::None.boxed(),
-            // https://tailwindcss.com/docs/grid-auto-flow
-            ["flow", _rest @ ..] => TailwindListStyle::None.boxed(),
-            // https://tailwindcss.com/docs/place-self
-            ["self", _rest @ ..] => TailwindListStyle::None.boxed(),
-            _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
+
     #[inline]
     fn justify_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
@@ -383,34 +363,30 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-    #[inline]
-    fn list_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/list-style-type
-            ["none"] => TailwindListStyle::None.boxed(),
-            ["disc"] => TailwindListStyle::Disc.boxed(),
-            ["decimal"] => TailwindListStyle::Decimal.boxed(),
-            // https://tailwindcss.com/docs/list-style-position
-            ["inside"] => TailwindListStylePosition::Inside.boxed(),
-            ["outside"] => TailwindListStylePosition::Outside.boxed(),
-            // https://tailwindcss.com/docs/list-style-type#arbitrary-values
-            [] => TailwindListStyle::parse_arbitrary(arbitrary)?.boxed(),
-            _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
 
     #[inline]
     fn backdrop_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
         let out = match str {
-            // https://tailwindcss.com/docs/justify-content
-            ["content", _rest @ ..] => TailwindListStyle::None.boxed(),
-            // https://tailwindcss.com/docs/justify-items
-            ["items", _rest @ ..] => TailwindListStyle::None.boxed(),
-            // https://tailwindcss.com/docs/justify-self
-            ["self", _rest @ ..] => TailwindListStyle::None.boxed(),
-            _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
+            // https://tailwindcss.com/docs/backdrop-blur
+            ["blur", rest @ ..] => TailwindBlur::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-brightness
+            ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-contrast
+            ["contrast", rest @ ..] => TailwindContrast::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-grayscale
+            ["grayscale", rest @ ..] => TailwindGrayscale::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-hue-rotate
+            ["hue", "rotate", rest @ ..] => TailwindHueRotate::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-invert
+            ["invert", rest @ ..] => TailwindInvert::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-opacity
+            ["opacity", rest @ ..] => TailwindOpacity::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-saturate
+            ["saturate", rest @ ..] => TailwindSaturate::parse(rest, arbitrary, true)?.boxed(),
+            // https://tailwindcss.com/docs/backdrop-sepia
+            ["sepia", rest @ ..] => TailwindSepia::parse(rest, arbitrary, true)?.boxed(),
+            _ => return syntax_error!("Unknown backdrop instructions: {}", str.join("-")),
         };
         Ok(out)
     }
